#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SBITS_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SBITS_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/sbits.hpp>

#endif
